@@ -141,6 +141,8 @@ extern struct _StatsOptions *last_stats_options;
     KW_TYPE = 10083,
     KW_STATS_MAX_DYNAMIC = 10084,
     KW_MIN_IW_SIZE_PER_READER = 10085,
+    KW_BATCH_LINES = 10087,
+    KW_BATCH_TIMEOUT = 10088,
     KW_CHAIN_HOSTNAMES = 10090,
     KW_NORMALIZE_HOSTNAMES = 10091,
     KW_KEEP_HOSTNAME = 10092,
@@ -286,6 +288,8 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_TYPE 10083
 #define KW_STATS_MAX_DYNAMIC 10084
 #define KW_MIN_IW_SIZE_PER_READER 10085
+#define KW_BATCH_LINES 10087
+#define KW_BATCH_TIMEOUT 10088
 #define KW_CHAIN_HOSTNAMES 10090
 #define KW_NORMALIZE_HOSTNAMES 10091
 #define KW_KEEP_HOSTNAME 10092
