@@ -76,7 +76,6 @@ struct _GlobalConfig
   gint mark_freq;
   gint flush_lines;
   gint mark_mode;
-  gint flush_timeout;
   gboolean threaded;
   gboolean pass_unix_credentials;
   gboolean chain_hostnames;
@@ -112,12 +111,16 @@ struct _GlobalConfig
   LogTemplate *file_template;
   LogTemplate *proto_template;
 
+  guint min_iw_size_per_reader;
+
   PersistConfig *persist;
   PersistState *state;
   GHashTable *module_config;
 
   CfgTree tree;
 
+  GString *preprocess_config;
+  GString *original_config;
 };
 
 gboolean cfg_load_module(GlobalConfig *cfg, const gchar *module_name);
@@ -128,8 +131,8 @@ gpointer cfg_parse_plugin(GlobalConfig *cfg, Plugin *plugin, YYLTYPE *yylloc, gp
 gboolean cfg_allow_config_dups(GlobalConfig *self);
 
 void cfg_bad_hostname_set(GlobalConfig *self, gchar *bad_hostname_re);
-gint cfg_lookup_mark_mode(gchar *mark_mode);
-void cfg_set_mark_mode(GlobalConfig *self, gchar *mark_mode);
+gint cfg_lookup_mark_mode(const gchar *mark_mode);
+void cfg_set_mark_mode(GlobalConfig *self, const gchar *mark_mode);
 
 gint cfg_tz_convert_value(gchar *convert);
 gint cfg_ts_format_value(gchar *format);
@@ -143,7 +146,6 @@ GlobalConfig *cfg_new(gint version);
 GlobalConfig *cfg_new_snippet(void);
 gboolean cfg_run_parser(GlobalConfig *self, CfgLexer *lexer, CfgParser *parser, gpointer *result, gpointer arg);
 gboolean cfg_read_config(GlobalConfig *cfg, const gchar *fname, gboolean syntax_only, gchar *preprocess_into);
-gboolean cfg_load_config(GlobalConfig *self, gchar *config_string, gboolean syntax_only, gchar *preprocess_into);
 void cfg_load_forced_modules(GlobalConfig *self);
 void cfg_shutdown(GlobalConfig *self);
 void cfg_free(GlobalConfig *self);
